/*
 * File: ERFFileImportDialog.java
 * Created on 11 sept. 2003
 *
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package NWNDialogEditorInterface;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.util.ResourceBundle;
import java.util.Vector;

import javax.swing.*;
import javax.swing.border.BevelBorder;

import NWNFiles.ERFFile;
import NWNFiles.ERFResourceEntry;
import NWNLanguages.KeysHolder;
import NWNLanguages.Languages;

/**
 * 11 sept. 2003
 * @author Alexandre Brunel
 *
 * TODO NWNDialogEditorInterface.ERFFileImportDialog documentation
 */
public class ERFFileImportDialog extends JDialog implements ActionListener
{

    private Vector indexesVector;

    private File extractedFile;

    private JButton cancelButton;

    private JButton endButton;

    private JPanel fileSelectionPannel;

    private ERFFile erfFile;

    private File selectedFile;

    private ERFFileChooser fileChooser;

    private JTextField erfFileName;

    private JButton erfChooserButton;

    private JList fileList;

    private Languages resourceBundle;

    private File initialDirectory;

    /**
     * TODO NWNDialogEditorInterface.ERFFileImportDialog Constructor documentation.
     * Constructs a ERFFileImportDialog object.
     * @throws java.awt.HeadlessException
     */
    public ERFFileImportDialog(File initialDirectory, JFrame parent) throws HeadlessException
    {
        super(parent);

        resourceBundle = (Languages) ResourceBundle.getBundle(KeysHolder.LanguagesBaseName);

        this.initialDirectory = initialDirectory;

        init();

    }

    /**
     * TODO ERFFileImportDialog.init
     * 
     */
    private void init()
    {
        setTitle(resourceBundle.getString(KeysHolder.ERFFileInportDialogTitle));

        fileList = new JList();
        fileList.setPreferredSize(new Dimension(100, 200));
        fileList.setBorder(new BevelBorder(BevelBorder.LOWERED));

        erfChooserButton =
            new JButton(resourceBundle.getString(KeysHolder.ERFFileInportDialogERFButton));
        erfChooserButton.setMnemonic(
            ((Number) resourceBundle.getObject(KeysHolder.ERFFileInportDialogERFButtonMnemonic))
                .intValue());
        erfChooserButton.addActionListener(this);

        erfFileName = new JTextField(20);
        erfFileName.setEditable(false);

        GridBagConstraints constraints = new GridBagConstraints();

        GridBagLayout tempLayout;

        //erfSelectionPannel = new JPanel(tempLayout);
        GridLayout tempGridLayout;
        fileSelectionPannel = new JPanel(tempGridLayout = new GridLayout(1, 2));
        tempGridLayout.setHgap(10);
        tempGridLayout.setVgap(10);

        fileSelectionPannel.setBorder(BorderFactory.createEtchedBorder());

        JPanel tempPanel = new JPanel(tempLayout = new GridBagLayout());

        constraints.gridy = 0;
        constraints.gridx = GridBagConstraints.RELATIVE;
        constraints.anchor = GridBagConstraints.WEST;

        JLabel tempLabel =
            new JLabel(resourceBundle.getString(KeysHolder.ERFFileInportDialogERFFileNameLabel));
        tempLayout.setConstraints(tempLabel, constraints);
        tempPanel.add(tempLabel);

        constraints.gridy = 1;
        tempLayout.setConstraints(erfFileName, constraints);
        tempPanel.add(erfFileName);

        tempLayout.setConstraints(erfChooserButton, constraints);
        tempPanel.add(erfChooserButton);

        fileSelectionPannel.add(tempPanel);

        tempPanel = new JPanel(new BorderLayout());

        tempPanel.add(fileList);
        tempPanel.setBorder(
            BorderFactory.createTitledBorder(
                resourceBundle.getString(KeysHolder.ERFFileInportDialogFileListLabel)));

        fileSelectionPannel.add(tempPanel);

        endButton = new JButton(resourceBundle.getString(KeysHolder.EndButton));
        endButton.setMnemonic(
            ((Number) resourceBundle.getObject(KeysHolder.EndButtonMnemonic)).intValue());
        endButton.setEnabled(false);
        endButton.addActionListener(this);

        cancelButton = new JButton(resourceBundle.getString(KeysHolder.CancelButton));
        cancelButton.setMnemonic(
            ((Number) resourceBundle.getObject(KeysHolder.CancelButtonMnemonic)).intValue());
        cancelButton.addActionListener(this);

        tempPanel = new JPanel(new FlowLayout(FlowLayout.RIGHT));

        tempPanel.add(cancelButton);

        tempPanel.add(endButton);

        getContentPane().add(fileSelectionPannel, BorderLayout.CENTER);
        getContentPane().add(tempPanel, BorderLayout.SOUTH);

        tempPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));

        tempPanel.setBackground(Color.WHITE);

        tempPanel.add(
            tempLabel =
                new JLabel(
                    resourceBundle.getString(KeysHolder.ERFFileInportDialogFileSelectionTitle)));

        tempLabel.setFont(
            new Font(
                tempLabel.getFont().getName(),
                Font.BOLD,
                (int) (tempLabel.getFont().getSize() * 1.5)));
        getContentPane().add(tempPanel, BorderLayout.NORTH);

        pack();
    }

    /* (non-Javadoc)
     * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
     */
    public void actionPerformed(ActionEvent e)
    {
        if (e.getSource() == this.erfChooserButton)
        {

            if (fileChooser == null)
            {
                fileChooser = new ERFFileChooser(initialDirectory);
            }

            if (fileChooser.showOpenDialog(this) == JFileChooser.APPROVE_OPTION)
            {

                File temp = fileChooser.getSelectedFile();

                erfFile = fileChooser.getSelectedERFFile();

                erfFileName.setText(temp.getAbsolutePath());

                Vector tempVector = new Vector();
                indexesVector = new Vector();
                for (int i = 0; i < erfFile.getFileNumber(); i++)
                {
                    ERFResourceEntry entry = erfFile.getResourceEntry(i);

                    if (ERFResourceEntry
                        .GetExtension(new Integer(entry.getFileType()))
                        .equalsIgnoreCase("dlg"))
                    {
                        tempVector.add(entry.getFileName());
                        indexesVector.add(new Integer(i));
                    }
                }

                fileList.setListData(tempVector);

                if (tempVector.size() > 0)
                {
                    endButton.setEnabled(true);
                    fileList.setSelectedIndex(0);
                }
                else
                {
                    endButton.setEnabled(false);
                }
            }
        }
        else if (e.getSource() == endButton)
        {
            File temp = null;
            try
            {
                temp = File.createTempFile("temp", "ghanima");
                temp.deleteOnExit();
            }
            catch (IOException e1)
            {
                JOptionPane.showMessageDialog(
                    this,
                    e1.getLocalizedMessage(),
                    resourceBundle.getString(KeysHolder.ErrorDialogsTitle),
                    JOptionPane.ERROR_MESSAGE);
                e1.printStackTrace();
            }

            try
            {
                extractedFile =
                    erfFile.getResourceEntry(((Number)indexesVector.get(fileList.getSelectedIndex())).intValue()).extract(
                        temp.getParentFile());
            }
            catch (ArrayIndexOutOfBoundsException e2)
            {
                JOptionPane.showMessageDialog(
                    this,
                    e2.getLocalizedMessage(),
                    resourceBundle.getString(KeysHolder.ErrorDialogsTitle),
                    JOptionPane.ERROR_MESSAGE);
            }
            catch (IOException e2)
            {
                JOptionPane.showMessageDialog(
                    this,
                    e2.getLocalizedMessage(),
                    resourceBundle.getString(KeysHolder.ErrorDialogsTitle),
                    JOptionPane.ERROR_MESSAGE);
            }

//            JOptionPane.showMessageDialog(this, resourceBundle.getString(KeysHolder.ERF), title, PROPERTIES)
            dispose();
        }
        else if (e.getSource() == cancelButton)
        {
            dispose();
        }
    }

    /**
     * TODO File ERFFileImportDialog.getExtractedFile
     * @return
     */
    public File getExtractedFile()
    {
        return extractedFile;
    }

}
