/*
 * Created on 16 juil. 2003
 * Author: Alexandre Brunel
 * 
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * NWNDialogEditorInterface.InterfaceThread declaration.
 */
package NWNDialogEditorInterface;

import java.lang.reflect.InvocationTargetException;

/**
 * 16 juil. 2003
 * @author Alexandre Brunel
 *
 * This class alows to create a new thread for long jobs.
 */
public class InterfaceThread extends Thread
{

    private Class[] argsClasses;

    private Object targetObject;

    private String method;
    
    private Object[] args;

    /**
     * Constructs a InterfaceThread object.
     * 
     * The tread will run the methode methodeName on the object target.
     * 
     * @param methodeName Methode to run.
     * @param target Object on which the methode should be run.
     */
    public InterfaceThread(String methodName,Object target,Object[] _args)
    {
        super(target.getClass().getName() + "." + methodName); //$NON-NLS-1$
        
        method = methodName;
        
        targetObject = target;
        
        args = _args;
    }
	
	
    /* (non-Javadoc)
     * @see java.lang.Runnable#run()
     */
    public void run()
    {
        try
        {
            if(argsClasses == null && args != null)
            {
            
	            argsClasses = new Class[args.length];
	            
	            for (int i = 0; i < argsClasses.length; i++)
	            {
	                argsClasses[i] = args[i].getClass();
	            }
            }
            
            targetObject.getClass().getDeclaredMethod(method,argsClasses).invoke(targetObject,args);
        }
        catch (IllegalArgumentException e)
        {
            
            e.printStackTrace();
        }
        catch (SecurityException e)
        {
            
            e.printStackTrace();
        }
        catch (IllegalAccessException e)
        {
            
            e.printStackTrace();
        }
        catch (InvocationTargetException e)
        {
            
            e.printStackTrace();
        }
        catch (NoSuchMethodException e)
        {
            
            e.printStackTrace();
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
        catch(Throwable e)
        {
        	e.printStackTrace();
        }
       
    }

    /**
     * @return Method argument list.
     */
    public Object[] getArgs()
    {
        return args;
    }

    /**
     * @return Method name.
     */
    public String getMethod()
    {
        return method;
    }

    /**
     * @return The target object.
     */
    public Object getTargetObject()
    {
        return targetObject;
    }

    /**
     * @param objects The new argument list.
     */
    public void setArgs(Object[] objects)
    {
        args = objects;
        argsClasses = null;
    }

    /**
     * @param string The new method name.
     */
    public void setMethod(String string)
    {
        method = string;
    }

    /**
     * @param object The new target object.
     */
    public void setTargetObject(Object object)
    {
        targetObject = object;
    }

}
