/*
 * File: SidePanel.java
 * Created on 13 sept. 2003
 *
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package NWNDialogEditorInterface;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.File;
import java.io.FileNotFoundException;
import java.util.Observable;
import java.util.Observer;
import java.util.ResourceBundle;
import java.util.Vector;

import javax.swing.*;
import javax.swing.border.BevelBorder;

import NWNFiles.ERFFile;
import NWNFiles.ERFResourceEntry;
import NWNFiles.NWNFile;
import NWNFiles.NWNFilesExceptions.FileDoesNotExist;
import NWNFiles.NWNFilesExceptions.InvalidFile;
import NWNFiles.NWNFilesExceptions.NameTooLong;
import NWNLanguages.KeysHolder;
import NWNLanguages.Languages;

/**
 * 13 sept. 2003
 * @author Alexandre Brunel
 *
 * TODO NWNDialogEditorInterface.SidePanel documentation
 */
public class SidePanel extends JPanel implements PropertyChangeListener, Observer
{

    private ResourceBundle nwnFileLanguageBundle;

    private JProgressBar progressBar;

    private ERFFile selectedFile;

    private Languages resourceBundle;

    private JList erfContentList;
    

    /**
     * TODO NWNDialogEditorInterface.SidePanel Constructor documentation.
     * Constructs a SidePanel object.
     * @param ERFFileChooser
     */
    public SidePanel()
    {

        init();
    }

    /**
     * TODO SidePanel.init
     * 
     */
    private void init()
    {

        resourceBundle = (Languages) ResourceBundle.getBundle(KeysHolder.LanguagesBaseName);
        nwnFileLanguageBundle = ResourceBundle.getBundle(NWNFiles.language.KeysHolder.LanguagesBaseName);
        
        erfContentList = new JList();
        setLayout(new BorderLayout());
        //this = new JPanel(new BorderLayout());

        JLabel listLabel =
            new JLabel(resourceBundle.getString(KeysHolder.ERFFileInportDialogListLabel));

        erfContentList.setPreferredSize(new Dimension(200, 100));

        erfContentList.setBorder(BorderFactory.createBevelBorder(BevelBorder.LOWERED));

        progressBar = new JProgressBar(JProgressBar.HORIZONTAL, 0, 100);

        this.add(listLabel, BorderLayout.NORTH);
        this.add(erfContentList, BorderLayout.CENTER);
        this.add(progressBar, BorderLayout.SOUTH);
        
        

    }

    /* (non-Javadoc)
    	 * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
    	 */
    public void propertyChange(PropertyChangeEvent evt)
    {
        if (evt.getPropertyName().equals(JFileChooser.SELECTED_FILE_CHANGED_PROPERTY))
        {
            try
            {
                if (selectedFile != null)
                {
                    selectedFile.deleteObserver(this);
                }
                if (evt.getNewValue() != null && !((File) evt.getNewValue()).isDirectory())
                {

                    selectedFile = new ERFFile((File) evt.getNewValue(), this);

                    Vector files = new Vector();

                    for (int i = 0; i < selectedFile.getFileNumber(); i++)
                    {
                        ERFResourceEntry entry = selectedFile.getResourceEntry(i);
                        if (entry.getFileType() == ERFResourceEntry.GetID("dlg"))
                        {

                            files.add(
                                entry.getFileName()
                                    + "."
                                    + ERFResourceEntry.GetExtension(
                                        new Integer(entry.getFileType())));
                        }
                    }

                    erfContentList.setListData(files);
                }
            }
            catch (FileDoesNotExist e)
            {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
            catch (InvalidFile e)
            {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
            catch (NameTooLong e)
            {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
            catch (FileNotFoundException e)
            {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
            catch (ClassCastException e)
            {
				e.printStackTrace();
				// TODO: handle exception
            }
        }
        else if (evt.getPropertyName().equalsIgnoreCase(JFileChooser.DIRECTORY_CHANGED_PROPERTY))
        {
            erfContentList.removeAll();
        }
    }

    /* (non-Javadoc)
     * @see java.util.Observer#update(java.util.Observable, java.lang.Object)
     */
    public void update(Observable o, Object arg)
    {
        
        NWNFile.FileState state = (NWNFile.FileState)arg;
        if (state.getOperation().equals(nwnFileLanguageBundle.getString(NWNFiles.language.KeysHolder.LoadOperation)))
        {
        	progressBar.setValue((int)(100.*state.getProgress()));
        	
        }
        else if (state.getOperation().equals(nwnFileLanguageBundle.getString(NWNFiles.language.KeysHolder.LoadOperationDone)))
        {
            progressBar.setValue(0);
        }

    }
    
    
    /**
     * TODO SidePanel.setFile
     * @param newFile
     */
    public void setFile(File newFile)
    {
        
    }
    /**
     * @return
     */
    public ERFFile getSelectedFile()
    {
        return selectedFile;
    }

}