/*
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package NWNFiles.GFFFieldTypes;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;

import NWNFiles.language.KeysHolder;
/** CExoString data type*/
public class FieldTypeCExoString extends FieldType
{
	FieldTypeCExoString()
	{
		super(FieldType.CExoString_TYPE,true);
	}
	/**
	  * Returns the string stored in the buffer.
	  * @param buffer A buffer containing the data. The current position of the buffer should be the biginning of the data.
	  * @return a String object.
	  */
	public Object interpretData(ByteBuffer buffer)
	{
		byte[] read = new byte[4];
		
		buffer.get(read);
		
		long stringSize = ((int)read[0])&0xFF;
		stringSize |= (((int)read[1])&0xFF) << 8;
		stringSize |= (((int)read[2])&0xFF) << 16;
		stringSize |= (((int)read[3])&0xFF) << 24;
		
		read = new byte[(int)stringSize];
		
		buffer.get(read);
		
		String string;
		try
		{
			
			string = new String(read,0,(int)stringSize,Charset.forName(CurrentLanguage.getString(KeysHolder.BinaryCarset)).name());
		}
		catch(java.io.UnsupportedEncodingException e)
		{
			string = null;
		}
		
		return string;
	}
	/**
	  * Returns an array containing a CExoString, ready to be stored in the GFF file..
	  * @param data Should be a String object.
	  */
	public byte[] getData(Object data)
	{
		String string = (String)data;
		int stringLength = (string.length() <= 1024 ? string.length():1024);
		
		byte[] retval = new byte[stringLength+4];
		
		retval[0] = (byte)stringLength;
		retval[1] = (byte)(stringLength >> 8);
		retval[2] = (byte)(stringLength >> 16);
		retval[3] = (byte)(stringLength >> 24);
		
		byte[] temp;
		
		try
		{
			temp = string.getBytes(Charset.forName(CurrentLanguage.getString(KeysHolder.BinaryCarset)).name());
		}
		catch(java.io.UnsupportedEncodingException e)
		{
			temp = new byte[0];
		}
		
		((ByteBuffer)ByteBuffer.wrap(retval).position(4)).put(temp,0,(int)stringLength);
		
		return retval;
	}
}
