/*
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package NWNFiles.GFFFieldTypes;
import java.nio.ByteBuffer;
/**DWORD data type*/
public class FieldTypeDWORD64 extends FieldType
{
	/**Represents a DWORD*/
	public static class DWORD64
	{
		private long highOrderDWord;
		private long lowOrderDWord;
		
		/**Returns the high order DWORD*/
		public long getHighOrderDWord() {
			return highOrderDWord;
		}
		/**Returns the low order DWORD*/
		public long getLowOrderDWord() {
			return lowOrderDWord;
		}
		/**Constructs a DWORD64.
		  *@param _highOrderDWord high order DWORD.
		  *@param _lowOrderDWord low order DWORD.
		  */
		public DWORD64(long _highOrderDWord,long _lowOrderDWord)
		{
			highOrderDWord = _highOrderDWord;
			lowOrderDWord = _lowOrderDWord;
		}

	}
	
	FieldTypeDWORD64()
	{
		super(FieldType.DWORD64_TYPE,true);
	}
	/**
	  * Returns a DWORD64 containing the DWORD64 value.
	  * @param buffer A buffer containing the data. The current position of the buffer should be the biginning of the data.
	  * @return A DWORD64 object.
	  */
	public Object interpretData(ByteBuffer buffer)
	{
		byte[] read = new byte[8];
		buffer.get(read);
		
		long highOrderDWord;
		long lowOrderDWord;
	
		lowOrderDWord  = ((long)read[0])&0xFF;
		lowOrderDWord |= (((long)read[1])&0xFF) << 8;
		lowOrderDWord |= (((long)read[2])&0xFF) << 16;
		lowOrderDWord |= (((long)read[3])&0xFF) << 24;
		
		
		highOrderDWord  = ((long)read[4])&0xFF;
		highOrderDWord |= (((long)read[5])&0xFF) << 8;
		highOrderDWord |= (((long)read[6])&0xFF) << 16;
		highOrderDWord |= (((long)read[7])&0xFF) << 24;
	
		return new DWORD64(highOrderDWord,lowOrderDWord);
	}
	/**
	  * Returns an array containing the DWORD64 value.
	  * @param data Should be a DWORD64 object.
	  */
	public byte[] getData(Object data)
	{
		long highOrderDWord = ((DWORD64)data).getHighOrderDWord();
		long lowOrderDWord  = ((DWORD64)data).getLowOrderDWord();
		
		byte[] retval = new byte[8];
		
		retval[0] = (byte)lowOrderDWord;
		retval[1] = (byte)(lowOrderDWord >> 8);
		retval[2] = (byte)(lowOrderDWord >> 16);
		retval[3] = (byte)(lowOrderDWord >> 24);
		retval[4] = (byte)highOrderDWord;
		retval[6] = (byte)(highOrderDWord >> 8);
		retval[6] = (byte)(highOrderDWord >> 16);
		retval[7] = (byte)(highOrderDWord >> 24);
		
		return retval;
	}
}
