/*
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package NWNFiles.GFFFieldTypes;
import java.nio.ByteBuffer;

/**INT data type*/
public class FieldTypeINT extends FieldType
{
	FieldTypeINT()
	{
		super(FieldType.INT_TYPE);
	}
	/**
	  * Returns an Integer object containing the signed int value.
	  * @param buffer A buffer containing the data. The current position of the buffer should be the biginning of the data.
	  * @return A Integer object.
	  */
	public Object interpretData(ByteBuffer buffer)
	{
		byte[] read = new byte[4];
		buffer.get(read);
		
		int value 	=  ((int)read[0])&0xFF;
		value 		= (((int)read[1])&0xFF) << 8;
		value 		= (((int)read[2])&0xFF) << 16;
		value 		= (((int)read[3])&0xFF) << 24;
		
		return new Integer(value);
	}
	/**
	  * Returns an array containing the int value.
	  * @param data Should be a Integer object.
	  */
	public byte[] getData(Object data)
	{
		int value = ((Integer)data).intValue();
		
		byte[] retval = new byte[4];
		
		retval[0] = (byte)value;
		retval[1] = (byte)(value >> 8);
		retval[2] = (byte)(value >> 16);
		retval[3] = (byte)(value >> 24);
		
		return retval;
	}
}
