/*
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package NWNFiles.GFFFieldTypes;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;

import NWNFiles.language.KeysHolder;

/**
 * @author Alexandre Brunel
 *
 * A class representing the RESREF data type.
 */
public class FieldTypeRESREF extends FieldType
{
	FieldTypeRESREF()
	{
		super(FieldType.RESREF_TYPE,true);
	}
	
	/**
	 * @param buffer A buffer containing the data. The current position of the buffer should be the biginning of the data and its length should be at least one byte.
	 * @return A String containing the data.
	 */
	public Object interpretData(ByteBuffer buffer)
	{
		byte[] read;
		
		
		
		int stringSize = ((int)buffer.get())&0xFF;
		
		
		read = new byte[stringSize];
		
		buffer.get(read);
		
		String string;
		try
		{
			
			string = new String(read,0,stringSize,Charset.forName(CurrentLanguage.getString(KeysHolder.BinaryCarset)).name());
		}
		catch(java.io.UnsupportedEncodingException e)
		{
			string = null;
		}
		
		return string;
	}
	
	/**
	 * @param data Should be a String object.
	 * @return A byte array containing the RESREF.
	 */
	public byte[] getData(Object data)
	{
		String string = (String)data;
		int stringLength = (string.length() <= 16 ? string.length():16);
		
		byte[] retval = new byte[stringLength+1];
		
		retval[0] = (byte)stringLength;
		
		byte[] temp;
		
		try
		{
			temp = string.getBytes(Charset.forName(CurrentLanguage.getString(KeysHolder.BinaryCarset)).name());
		}
		catch(java.io.UnsupportedEncodingException e)
		{
			temp = new byte[stringLength];
		}
		
		((ByteBuffer)ByteBuffer.wrap(retval).position(1)).put(temp,0,stringLength);
		
		return retval;
	}
}
