/*
 *   Copyright 2003 Alexandre Brunel
 * 
 *   This file is part of Ghanima beta version 1.
 * 
 *   Ghanima is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */
package NWNFiles;
import java.util.Observable;
import java.util.ResourceBundle;

import NWNFiles.language.KeysHolder;

public abstract class NWNFile extends Observable 
{
	public static class FileState implements Cloneable
	{
		private boolean modified;
		private String operation;
		private float progress;
		
		public boolean isModified() {
			return modified;
		}
		
		public String getOperation() {
			return operation;
		}
		
		public float getProgress() {
			return progress;
		}
		
		public FileState(String _operation,float _progress)
		{
			modified = false;
			operation = _operation;
			progress = _progress;
		}
		
		public FileState(boolean _modified,String _operation,float _progress)
		{
			modified = _modified;
			operation = _operation;
			progress = _progress;
		}
		
		public Object clone() throws java.lang.CloneNotSupportedException
		{
			FileState retval = (FileState)super.clone();
			
			retval.modified  = modified;
			retval.operation = operation;
			retval.progress  = progress;
			
			return retval;
		}
		
		protected void setModified(boolean modified) {
			this.modified = modified;
		}
		protected void setOperation(String operation) {
			this.operation = operation;
		}
		protected void setProgress(float progress) {
			this.progress = progress;
		}


	}
	
	protected ResourceBundle currentLanguage;

    protected FileState fileState;
	
	public FileState getFileState() {
		return fileState;
	}

	
	public NWNFile()
	{
		super();
		fileState = new FileState("",0.0f); //$NON-NLS-1$
		currentLanguage = ResourceBundle.getBundle(KeysHolder.LanguagesBaseName);
	}
    /**
     * @return
     */
    public ResourceBundle getCurrentLanguage()
    {
        return currentLanguage;
    }

    /**
     * @param bundle
     */
    public void setCurrentLanguage(ResourceBundle bundle)
    {
        currentLanguage = bundle;
    }

}
